---
id: an_intro_to_the_threefold_grid
title: "Building a New Internet From the Ground Up – Part 1: Introduction"
image_caption: The ThreeFold Grid Peer-to-Peer Technology
description: The first episode in an approachable series on the inner workings of the ThreeFold Grid.
date: 2021-07-19
taxonomies:
    tags: [threefold,technology,peer_to_peer]
    categories: [threefold,farming]
extra:
    author: scott_yeager
    imgPath: an_intro_to_the_threefold_grid.png
---

## An Intro to the ThreeFold Grid

If you are a farmer or member of the ThreeFold community, you may be wondering about the capacity provided by the ThreeFold Grid and how it's relevant to individuals and businesses who currently rely on centralized corporate clouds. This can be hard to imagine, because the back end infrastructure that makes all of our apps and services tick is generally invisible to us. 

<br>

This piece will be the first in a series where I'll be working to understand what the technical components are and how ThreeFold provides an alternative with distinct benefits for individuals, businesses, and for the planet as a whole. But don't worry, we'll start from the ground level and build up understanding in a way that's accessible to everyone.

## Infrastructure for a New Internet

So, what is the internet? In short, it is a network of interconnected devices that facilitates communication and commerce. These devices include our mobile phones and personal computers, but also the servers that store and process data to provide the end experiences we enjoy. Currently the vast majority of these servers live in massive data centers controlled by a handful of corporations. ThreeFold is changing this, by allowing anyone to connect computational and storage capacity to an open network that is available for all to use, known as the ThreeFold Grid. Our farmers do include some data centers operating on a smaller scale than major cloud providers, and also many individuals connecting nodes at their home or office all over the world.

<br>

On the ThreeFold Grid, servers are known as 3Nodes. A 3Node can be pretty much any modern computer system, offering capacity by running the Zero OS operating system. This is a major distinguishing factor, both from the traditional cloud computing world and also from other projects working to create decentralized networks in this space. 

## The OS for a Next Generation Cloud

By starting from the operating system level, ThreeFold is able to provide a network with much stronger security and greater efficiency than anything that came before. Zero OS includes a collection of components, known as "primitives", which provide developers with everything they need. These primitives can be used to migrate existing applications from the legacy cloud and also to create new solutions that leverage the Grid’s capacity in unique ways.

<br>

We're all familiar with operating systems like Windows and MacOS that provide an interface to applications on our personal computers. The OS interacts with the underlying hardware to expose its capabilities in a way that's useful for both the software it hosts and also the humans who utilize it. For example, when you launch an app on your phone, it is the OS that's responsible for connecting it to data networks and providing access to peripherals like cameras or microphones. Things are a little different in the world of servers, where rather than through direct interactions, users benefit through the services provided to the applications we use.

<br>

To extend the example, when you open a messaging app it will connect to a server somewhere to check for new messages and relay any messages you are sending to the recipient. Here we can see a central issue that has inspired the design of ThreeFold’s technology: when our messages pass through servers controlled by others, it creates an open door for surveillance of all kinds.

<br>

ThreeFold farmers, on the other hand, have no administrative access to their nodes. Furthermore, each component offered by the ThreeFold Grid is built with the intention of allowing for secure and private storage, processing, and transmission of information. Of course, sharing is absolutely possible, but only when the creator of data or content chooses for it to happen.

## Three Essential Resources

In the world of cloud computing, we speak of three basic resources provided by servers: compute, storage, and network. The ThreeFold Grid provides various primitives in each of these     categories, to fulfill all the same needs served by centralized cloud providers. While our offerings have the special properties discussed above, they are also highly compatible with the most popular tools and protocols currently used in the industry. This makes it relatively simple to migrate the back end applications, also known as "workloads", that provide a kind of connective tissue for all of the digital experiences we enjoy on a daily basis.

<br>

Workloads are pieces of software that provide services. If you upload a file to some cloud storage service, there could be a number of individual workloads orchestrated together in order to ensure the data you want to save is successfully transmitted to and stored in the back end system. We can understand the need for each kind of capacity by looking at the journey that your file might take in such a scenario. Starting on your device, a network connection, some processing, and finally storage capacity are all involved in providing the conditions that allow you to retrieve that file later.

## Network

Networking takes place over cellular connections, wifi, and wired internet lines to move data from one place to another. For our purposes here, those details aren't so important—we'll focus on what happens once communication is completed by whatever means. 

<br>

When you connect to the cloud storage service, there are network workloads that transmit your data to the appropriate services that process and store it. This might consist of some routing and also authentication that ensures that you and only you access the files that are associated with your account. On the Grid, we provide primitives for secure peer to peer communication and also for allowing public access to back end services.

## Compute

Compute is what happens with data once it reaches its destination. Computers are mostly just fancy adding machines that take numbers and turn them into other numbers according to a set of specifications, which we call software. In our example, the compute step might involve compressing the information so it takes up less space and also deriving some useful statistics like the file's original size. 

<br>

Of course, there are many details we're glossing over here, and the compute resources are ultimately responsible for providing much of our end user experience and the interactivity of the apps we utilize. 3Nodes offer a compute environment that natively runs the vast majority of workloads in use today. 

## Storage

Storage, of course, is the disk space where data resides. It can be a little strange to think about, actually, that all of the information you've stored online actually has at least one physical location where it exists as many small electrical charges. On the Grid, application developers can access the disks of nodes directly, in a way that's optimized for energy efficiency. 

<br>

We also have more advanced storage solutions that offer unparalleled security and low overhead redundancy, giving users the best possible guarantee that only they have access to their data and that it will actually be there when they go to retrieve it.

## Looking Forward

Taken together, network, storage, and compute are the raw elements that give life to the internet we know and love. On the ThreeFold Grid, these elements are expressed in a way that's both familiar for developers but also pushes the limits of what is possible in terms of technical evolution. 

<br>

Thanks so much for joining me on this introductory overview of what the Grid provides. Please join me next time for a deeper dive on some of what we've covered and more specifics about how ThreeFold technology represents a quantum leap for cloud computing.
