---
id: cyberwar
title: Can a 'Democratized' Internet exist in times of a Cyber War?
image_caption: The Cyber War
description: With cyber sovereignty turning into a non-territorial challenge to sovereignty itself irrespective of the virtual realm of the internet, is there a way out for humanity?
date: 2022-03-03
taxonomies:
    tags: [peer_to_peer,why,technology]
    categories: [foundation]
extra:
    author: sacha_obeegadoo
    imgPath: cyberwar.png
---

On February 24 2022, Russia launched a large-scale military invasion and attack on Ukraine. In the days since the invasion began, the war has been fought not only on the ground and in the air, but also in the digital realm.

<br/>

Cyber warfare is nothing new, especially in Russia and Eastern Europe. “In the relatively short and rapidly evolving history of cyber conflict, perhaps nothing has been established with greater certainty and more widely accepted than the idea that Russia has significant cyber capabilities and isn’t afraid to use them,” [writes Josephine Wolff](https://time.com/6153902/russia-major-cyber-attacks-invasion-ukraine/), associate professor of cybersecurity policy at Tufts University. “Especially on Ukraine.”

<br/>

Leading up to the invasion, Ukraine experienced a series of cyberattacks on its critical infrastructures, including banks and government agencies. On February 23 2022, just a day before the launch of Russia’s military attack, websites of the Ukrainian parliament and multiple government agencies were put out of work. Similar cyber attacks had also been seen in early February and [were attributed to GRU](https://www.economist.com/europe/2022/02/23/will-war-in-ukraine-lead-to-a-wider-cyber-conflict?utm_campaign=a.io&utm_medium=audio.podcast.np&utm_source=babbage&utm_content=discovery.content.anonymous.tr_shownotes_na-na_article&utm_term=sa.listeners), Russia’s military-intelligence agency. And Ukrainian cities continue to suffer from [internet blackouts](https://www.economist.com/graphic-detail/2022/02/26/ukrainian-cities-are-suffering-internet-blackouts?utm_campaign=a.io&utm_medium=audio.podcast.np&utm_source=babbage&utm_content=discovery.content.anonymous.tr_shownotes_na-na_article&utm_term=sa.listeners). On Sunday, Ukraine’s vice president even called for tech specialists and hackers to join the “cyber front.” While the predictions of a Russian “cyber onslaught” have not necessarily come true yet, both sides have engaged in cyber attacks on visible and invisible levels.

## A Rise in State-Sponsored Cyber Attacks Globally

Digital or cyber warfare does not just apply to Russia and Ukraine. Broadly, cybersecurity experts have been raising concerns in recent years amid a sharp rise in ransomware and other types of digital attacks globally.

<br/>

Adam Meyers, Senior Vice President of Intelligence at the cybersecurity firm CrowdStrike [said](https://www.marketplace.org/2022/02/24/cybersecurity-to-take-center-stage-as-conflict-continues-in-ukraine/): “Just in the last year, I think we’ve seen over 2,700 big-game hunting attacks [cyberattacks that target high-value data]. So they’re far and away that most prevalent actor. Nation-state actors are continuously operating as well, but they tend to operate a little bit more under the radar. They don’t conduct as many widespread and widely known attacks. They try to, obviously, steal information without it being identified that they’ve stolen it.”

<br/>

Nevertheless, these are just the most current examples – Russia is hardly the only country engaging in cyber warfare at a larger scale. In fact, it is becoming increasingly difficult for governments, corporations and organizations to protect themselves against cyber attacks, especially against [state-sponsored attacks](https://www.economist.com/business/2022/02/19/companies-have-a-lot-to-fear-from-russias-digital-warmongering?utm_campaign=a.io&utm_medium=audio.podcast.np&utm_source=babbage&utm_content=discovery.content.anonymous.tr_shownotes_na-na_article&utm_term=sa.listeners). And in the digital space, the best and most dangerous hacks are those that go unnoticed until it’s too late.

## Some Governments are Sectioning Off the Internet Through Digital Borders

A set of countries like Russia, China, Saudi Arabia, and Iran have certain [aspirations for the internet](https://www.codastory.com/authoritarian-tech/global-rise-internet-sovereignty/). Domestically, these countries want control and think governments should get to decide what information flows across their borders. Globally, they want governments, not companies and NGOs, to be in charge of the internet. While some may say that government-owned internet infrastructures would be the only way to protect a country’s sovereignty, it goes without saying that what once was a neutral space for humanity to connect and exchange information is turning into a political schema.

<br/>

Taken together, these goals are an attempt to align cyberspace with national borders, so they are sometimes dubbed the [“cyber sovereignty” doctrine](https://www.codastory.com/authoritarian-tech/global-rise-internet-sovereignty/). The term comes from China, whose internet censorship system, called the Great Firewall, is the vanguard of the global cyber-sovereignty push. China’s cyberspace agency released a much-ridiculed musical ode to cybersecurity under Lu Wei’s leadership, which included the line: “A cyberpower: Where the Internet is, so is the glorious dream.”

<br/>

The vision of effective cyber-sovereignty is expanding to new horizons. A November [report](https://www.codastory.com/authoritarian-tech/global-rise-internet-sovereignty/) from Freedom House examined 65 countries and found since the previous year that internet freedom declined in 26 of them. Chinese-style “digital authoritarianism,” meanwhile, is growing in influence as China exports both its surveillance known-how and technology.

<br/>

The problem here is that digital sovereignty is a major concept that not only addresses the issues of communication and connection but also the impact on societies and culture at large. With cyber sovereignty turning into a non-territorial challenge to sovereignty itself irrespective of the virtual realm of the internet, is there a way out for humanity?

## A Free and Sovereign Cyber Space is Needed

It is evident that the current internet is facing some big challenges that have major implications for humanity. Data privacy and self-sovereignty is almost impossible today, raising serious questions towards those that control the Internet. But it also seems that these companies fell into the trap of their own business models and algorithms.

<br/>

When taking a step back, the world seems just a few years away from the Matrix, as depicted by the Wachowskis.

<br/>

The Internet is playing an incredibly important role for the most powerful intelligence companies. As depicted by Meyers, we wouldn’t even notice that our information is being stolen all the time to benefit the greed of powerful geo-political actors. The internet is not a public good anymore, and unless humanity reacts fast, it may be that the world will lose all forms of freedom or sovereignty.

<br/>

[“A declaration of the Independence of Cyberspace”](https://www.eff.org/cyberspace-independence) by John Perry Barlow once attempted to shed light on the applicability of government and institutions on the rapidly growing internet, already in 1996 trying to protect its neutrality. According to research, the world is experiencing innovation at an increasingly rapid pace. With the rise of blockchains and web3 technology, could the dream of John Perry Barlow turn into reality?

## So, What is the Solution?

In a world aching for more decentralization and less dependence on governments and corporations, new decentralized and peer-to-peer models are already proving to be more resilient and secure. New Internet infrastructure companies such as ThreeFold have successfully built peer-to-peer internet infrastructures that are more resilient than the current centralized model. On such systems, people and enterprises can store their data and run their applications on a distributed network of computers in such a way that their data cannot be corrupted. ThreeFold even created a so-called “quantum safe” storage that guarantees that even the most powerful computers in the world wouldn’t be able to reconstruct user data.

<br/>

The escalation of this cyber conflict can lead to unforeseen consequences and casualties. That is why it is especially important that our industry works together to protect customers, partners, employees and citizens. ThreeFold is on a mission to realize the promise of a fully-comprehensive, open-source and peer-to-peer internet infrastructure. ThreeFold is a platform for the creators of tomorrow to build that blueprint of responsibility and ensure that the outcome of future systems is neutrality.

<Br/>

Join ThreeFold in building the new internet.