---
id: internet_energy_consumption
title: "How to stop the Internet from Gobbling the World’s Energy"
image_caption: How to stop the Internet from Gobbling the World’s Energy
description: Oftentimes, the Internet’s significant energy consumption and climate impacts go unnoticed. At ThreeFold, we're leading the way by working on energy-efficient and sustainable solutions for the Internet.
date: 2022-04-26
taxonomies:
    tags: [threefold, why]
    categories: [threefold]
extra:
    author: hannah_cordes
    imgPath: internet_energy_consumption.png
---

*Global carbon emissions keep rising. Climate change and the collapse of biodiversity are accelerating faster than ever before. And yet, it’s important to believe in our ability to change our behaviour if we are to secure our children’s future. It’s not about being naive or optimistic, but rather a commitment to change and to do better. Across the globe, movements are sprouting to save our planet. How does ThreeFold take part in this? How are we contributing to making the world a better place?*  

<br/>

Once emitted, carbon can remain in our atmosphere for hundreds of years. To survive climate change, massive amounts of carbon emissions have to be offset – and fast. According to a UN report, [10 billion tons](https://www.technologyreview.com/2021/07/08/1027908/carbon-removal-hype-is-a-dangerous-distraction-climate-change/) of carbon emissions will have to be removed on a yearly basis by 2050 to prevent the planet from moving past the 2 degree Celsius threshold. Allowing the climate to heat by just one more degree would have unprecedented consequences – including the sinking of islands and coastal areas, an accelerated rate of extinction (right now, estimations suggest that about [24 to 150 species go extinct](https://e360.yale.edu/features/global_extinction_rates_why_do_estimates_vary_so_wildly) every day) and much more. Our complacency towards climate change proves that we’re still in denial of the chain reaction and butterfly effects of our past and present actions.

<br/>

Clearly, we’ve already crossed the threshold in the climate crisis where we had enough time for long debates on potential measures and policies. The time for those debates was in the 1960s, when a [report](https://www.climatefiles.com/climate-change-evidence/presidents-report-atmospher-carbon-dioxide/) by former US President Johnson’s Science Advisory Committee first warned about the risks and dangers of excessive carbon emissions. “Climate change is the result of more than a century of unsustainable energy and land use, lifestyles and patterns of consumption and production,” said Jim Skea, one of the IPCC Working Group III Co-Chairs in a [press release](https://www.enviro.or.id/2022/04/ipcc-press-release/) published earlier this month. According to [a report](https://www.ipcc.ch/report/sixth-assessment-report-working-group-3/) published by the Intergovernmental Panel on Climate Change (IPCC), we can still achieve our climate goals if we significantly reduce emissions across all economic sectors. However, we urgently need to take action to limit global warming to 1.5 degrees Celsius.

<br/>

Now is the time to act. Now is the time for bold moves. As Skea put it: “Without immediate and deep emissions reductions across all sectors, it will be impossible.”

## The astonishing carbon footprint of the Internet

While people are legitimately obsessing about the emissions caused by air travel and whether to take that plane or not – bestowing us with concepts like ‘flight shaming’ – other industries’ significant impacts almost go unnoticed. One of them is the Internet.

<br/>

Think about the [chat messages and emails](https://carbonliteracy.com/the-carbon-cost-of-an-email/) you send out every day. How many times do you [‘google’](https://www.fastcompany.com/90171268/internet_impact_visualized) things? How much time do you spend [streaming](https://www.carbontrust.com/resources/carbon-impact-of-video-streaming) music or videos? All of your online activities add to your carbon footprint. There are a couple grams of carbon emissions attached to the energy needed to power your devices and the wireless networks you connect to. On top of that comes the significant amount of energy required to support the infrastructure of today’s Internet, namely millions of data centers and the thousands of servers in each of them.

<br/>

Even though the emissions caused by streaming one song or sending one email may seem insignificant, the accumulated use of the Internet by billions of people all over the world adds up. It actually leads to a collective carbon footprint amounting to a share of roughly [3.7% of global emissions](https://www.bbc.com/future/article/20200305-why-your-internet-habits-are-not-as-clean-as-you-think) caused by the Internet and its infrastructure – and these carbon emissions are estimated[ to double](https://www.bbc.com/future/article/20200305-why-your-internet-habits-are-not-as-clean-as-you-think) within the next three years. This 3.7% share of global emissions by the Internet almost makes the global aviation industry with its estimated [2.1%](https://www.atag.org/facts-figures.html) emissions look good.

<br/>

The global pandemic – while decreasing emissions in aviation due to travel bans – has already accelerated Internet consumption and the resulting footprint due to increased streaming behaviour, remote work and more. With [1 billion people](https://www.cisco.com/c/en/us/solutions/executive-perspectives/annual-internet-report/index.html) and [75 billion IoT devices](https://www.statista.com/statistics/471264/iot-number-of-connected-devices-worldwide/#:~:text=Internet%20of%20Things%20%2D%20number%20of%20connected%20devices%20worldwide%202015%2D2025&text=By%202025%2C%20forecasts%20suggest%20that,IoT%20installed%20base%20in%202019.) expected to join the Internet economy by 2025, a more sustainable infrastructure than power-hungry data centers is urgently needed to meet the future growth of the Internet in an ethical and sustainable way.

## Data Centers are power hungry

Big tech corporations like Amazon, for example, have massive carbon footprints with their corporate facilities, power-hungry data centers, complex operations and more. One larger data center alone consumes up to [120 MW](https://www.datacenterdynamics.com/en/opinions/from-the-sensor-to-the-data-center/) – and there are about 7.2 million data centers worldwide, according to [Statista](https://www.statista.com/statistics/500458/worldwide-datacenter-and-it-sites/). Moreover, a data center’s energy consumption accounts for [about 40%](https://www.datacenterdynamics.com/en/opinions/from-the-sensor-to-the-data-center/) of its operating costs. In 2020, Amazon emitted more than [60 million metric tons](https://sustainability.aboutamazon.com/environment/sustainable-operations/carbon-footprint) of carbon dioxide up from about 51 million in 2019. Others like Google try to downplay their energy consumption by switching to renewable energy. While renewable energy is an improvement for sure, it does not change the fact that Google’s energy consumption could [power entire countries](https://www.forbes.com/sites/robertbryce/2020/10/21/googles-dominance-is-fueled-by-zambia-size-amounts-of-electricity/).

<br/>

Is that really a desirable way for us to use the still scarce supply of renewable energy? Shouldn’t we rather focus on the root problem and on becoming more energy efficient in the first place?

<br/>

The first step should be to reduce the Internet’s energy consumption and overall carbon footprint. But even then: reducing that energy consumption and transitioning to clean energy will only get us so far – particularly when considering that there simply is not enough clean energy to achieve a complete transition. Those emissions that cannot be cut have to be compensated for. A holistic solution to today’s Internet’s inefficiencies and emissions is needed.

## An energy-efficient and regenerative Internet

In December 2021, ThreeFold [announced](https://www.prnewswire.com/news-releases/threefold-and-take-action-global-partner-to-bring-internet-access-to-1-billion-people-across-the-globe-301446693.html) its commitment to achieve a carbon double win for its open-source peer-to-peer Internet infrastructure, the ThreeFold Grid. The ThreeFold Grid is able to scale anywhere electricity and network exist, using about 10 times less energy than any comparable alternative while being more affordable as well. By starting from scratch at the operating system level, ThreeFold was able to build an Internet infrastructure that is highly [energy efficient](https://threefold.io/blog/for_our_planet/). This infrastructure is already made up of thousands of 3Nodes that are spread across 75 countries and counting.

<br/>

Together with [Take Action Global](https://forum.threefold.io/t/driving-regeneration-with-tag/2120?u=hannahcordes) (TAG), an expert on climate education and action, ThreeFold aims to make the ThreeFold Grid planet-positive by removing its carbon emissions from the atmosphere three times in the form of [Voluntary Carbon Credits](https://forum.threefold.io/t/threefold-on-track-to-be-planet-positive/2097?u=hannahcordes). While the pilot for this initiative was announced to start in January 2022, ThreeFold and TAG were so eager to take action against climate change, they kicked-off the pilot one month early in December 2021. It is the first step in ThreeFold’s plan to support the use of ‘nature-based climate solutions’ like tree planting to absorb twice more carbon than the ThreeFold Grid emits by 2022. 

## A silver lining on the horizon

Every industry and organization has to pull their own weight. There is no way around it. Far-reaching actions and transformations are needed across industries to limit global warming to bearable levels. “The decisions we make now can secure a liveable future. We have the tools and know-how required to limit warming,” said Hoesung Lee, IPCC Chair, in an April 2022 [press release](https://www.enviro.or.id/2022/04/ipcc-press-release/). Together with TAG, ThreeFold leads the way by working on energy-efficient and sustainable solutions for the Internet. The new IPCC report gives us a reason to be optimistic about our future and have hope for the regeneration of our planet.

<br/>

Really, all it takes right now is widespread support and adoption of more energy-efficient, sustainable alternatives across industries like ThreeFold for the Internet – something that is up to each and every one of us. Let us all take action for a fairer, more sustainable world.

<br/>

* Join the global ThreeFold [movement](https://t.me/threefold).
* [Start farming](https://manual.grid.tf/farmers/farmers.html) today and support a greener Internet while regenerating the planet.
